@@ -393,7 +393,7 @@ static int handle_rkey_dereg(struct osmo_ss7_asp *asp, uint32_t rctx,
 		return -1;
 	}
 
-	rt = ss7_route_table_find_route_by_dpc(inst->rtable_system, as->cfg.routing_key.pc);
+	rt = ss7_route_table_find_route_by_dpc_mask(inst->rtable_system, as->cfg.routing_key.pc, 0xffffff);
 	if (!rt) {
 		msgb_append_dereg_res(resp, M3UA_RKM_DEREG_ERR_UNKNOWN, 0);
 		return -1;
@@ -548,7 +548,8 @@ static int m3ua_rx_rkm_dereg_rsp(struct osmo_ss7_asp *asp, struct xua_msg *xua)
 	return 0;
 }
 
-/* process an incoming RKM message in xua format */
+/* process an incoming RKM message in xua format
+ * This function takes ownership of xua msg passed to it. */
 int m3ua_rx_rkm(struct osmo_ss7_asp *asp, struct xua_msg *xua)
 {
 	int rc;
@@ -578,6 +579,8 @@ int m3ua_rx_rkm(struct osmo_ss7_asp *asp, struct xua_msg *xua)
 		rc = -1;
 		break;
 	}
+
+	xua_msg_free(xua);
 	return rc;
 }
 
